==> istio-model-v1alpha3-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/DestinationRuleSpecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface DestinationRuleSpecFluent<A extends DestinationRuleSpecFluent<A>> extends Fluent<A>{
  public A addToExportTo(Integer index,String item);
  public A setToExportTo(Integer index,String item);
  public A addToExportTo(java.lang.String... items);
  public A addAllToExportTo(Collection<String> items);
  public A removeFromExportTo(java.lang.String... items);
  public A removeAllFromExportTo(Collection<String> items);
  public List<String> getExportTo();
  public String getExportTo(Integer index);
  public String getFirstExportTo();
  public String getLastExportTo();
  public String getMatchingExportTo(Predicate<String> predicate);
  public Boolean hasMatchingExportTo(Predicate<String> predicate);
  public A withExportTo(List<String> exportTo);
  public A withExportTo(java.lang.String... exportTo);
  public Boolean hasExportTo();
  public String getHost();
  public A withHost(String host);
  public Boolean hasHost();
  public A addToSubsets(Integer index,Subset item);
  public A setToSubsets(Integer index,Subset item);
  public A addToSubsets(io.fabric8.istio.api.networking.v1alpha3.Subset... items);
  public A addAllToSubsets(Collection<Subset> items);
  public A removeFromSubsets(io.fabric8.istio.api.networking.v1alpha3.Subset... items);
  public A removeAllFromSubsets(Collection<Subset> items);
  public A removeMatchingFromSubsets(Predicate<SubsetBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubsets instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Subset> getSubsets();
  public List<Subset> buildSubsets();
  public Subset buildSubset(Integer index);
  public Subset buildFirstSubset();
  public Subset buildLastSubset();
  public Subset buildMatchingSubset(Predicate<SubsetBuilder> predicate);
  public Boolean hasMatchingSubset(Predicate<SubsetBuilder> predicate);
  public A withSubsets(List<Subset> subsets);
  public A withSubsets(io.fabric8.istio.api.networking.v1alpha3.Subset... subsets);
  public Boolean hasSubsets();
  public DestinationRuleSpecFluent.SubsetsNested<A> addNewSubset();
  public DestinationRuleSpecFluent.SubsetsNested<A> addNewSubsetLike(Subset item);
  public DestinationRuleSpecFluent.SubsetsNested<A> setNewSubsetLike(Integer index,Subset item);
  public DestinationRuleSpecFluent.SubsetsNested<A> editSubset(Integer index);
  public DestinationRuleSpecFluent.SubsetsNested<A> editFirstSubset();
  public DestinationRuleSpecFluent.SubsetsNested<A> editLastSubset();
  public DestinationRuleSpecFluent.SubsetsNested<A> editMatchingSubset(Predicate<SubsetBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTrafficPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public TrafficPolicy getTrafficPolicy();
  public TrafficPolicy buildTrafficPolicy();
  public A withTrafficPolicy(TrafficPolicy trafficPolicy);
  public Boolean hasTrafficPolicy();
  public DestinationRuleSpecFluent.TrafficPolicyNested<A> withNewTrafficPolicy();
  public DestinationRuleSpecFluent.TrafficPolicyNested<A> withNewTrafficPolicyLike(TrafficPolicy item);
  public DestinationRuleSpecFluent.TrafficPolicyNested<A> editTrafficPolicy();
  public DestinationRuleSpecFluent.TrafficPolicyNested<A> editOrNewTrafficPolicy();
  public DestinationRuleSpecFluent.TrafficPolicyNested<A> editOrNewTrafficPolicyLike(TrafficPolicy item);
  public interface SubsetsNested<N> extends Nested<N>,SubsetFluent<DestinationRuleSpecFluent.SubsetsNested<N>>{
    public N and();
    public N endSubset();
    
  }
  public interface TrafficPolicyNested<N> extends Nested<N>,TrafficPolicyFluent<DestinationRuleSpecFluent.TrafficPolicyNested<N>>{
    public N and();
    public N endTrafficPolicy();
    
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/DestinationRuleSpecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface DestinationRuleSpecFluent<A extends DestinationRuleSpecFluent<A>> extends Fluent<A>{
  public A addToExportTo(int index,String item);
  public A setToExportTo(int index,String item);
  public A addToExportTo(java.lang.String... items);
  public A addAllToExportTo(Collection<String> items);
  public A removeFromExportTo(java.lang.String... items);
  public A removeAllFromExportTo(Collection<String> items);
  public List<String> getExportTo();
  public String getExportTo(int index);
  public String getFirstExportTo();
  public String getLastExportTo();
  public String getMatchingExportTo(Predicate<String> predicate);
  public Boolean hasMatchingExportTo(Predicate<String> predicate);
  public A withExportTo(List<String> exportTo);
  public A withExportTo(java.lang.String... exportTo);
  public Boolean hasExportTo();
  public String getHost();
  public A withHost(String host);
  public Boolean hasHost();
  public A addToSubsets(int index,Subset item);
  public A setToSubsets(int index,Subset item);
  public A addToSubsets(io.fabric8.istio.api.networking.v1alpha3.Subset... items);
  public A addAllToSubsets(Collection<Subset> items);
  public A removeFromSubsets(io.fabric8.istio.api.networking.v1alpha3.Subset... items);
  public A removeAllFromSubsets(Collection<Subset> items);
  public A removeMatchingFromSubsets(Predicate<SubsetBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubsets instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Subset> getSubsets();
  public List<Subset> buildSubsets();
  public Subset buildSubset(int index);
  public Subset buildFirstSubset();
  public Subset buildLastSubset();
  public Subset buildMatchingSubset(Predicate<SubsetBuilder> predicate);
  public Boolean hasMatchingSubset(Predicate<SubsetBuilder> predicate);
  public A withSubsets(List<Subset> subsets);
  public A withSubsets(io.fabric8.istio.api.networking.v1alpha3.Subset... subsets);
  public Boolean hasSubsets();
  public DestinationRuleSpecFluent.SubsetsNested<A> addNewSubset();
  public DestinationRuleSpecFluent.SubsetsNested<A> addNewSubsetLike(Subset item);
  public DestinationRuleSpecFluent.SubsetsNested<A> setNewSubsetLike(int index,Subset item);
  public DestinationRuleSpecFluent.SubsetsNested<A> editSubset(int index);
  public DestinationRuleSpecFluent.SubsetsNested<A> editFirstSubset();
  public DestinationRuleSpecFluent.SubsetsNested<A> editLastSubset();
  public DestinationRuleSpecFluent.SubsetsNested<A> editMatchingSubset(Predicate<SubsetBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTrafficPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public TrafficPolicy getTrafficPolicy();
  public TrafficPolicy buildTrafficPolicy();
  public A withTrafficPolicy(TrafficPolicy trafficPolicy);
  public Boolean hasTrafficPolicy();
  public DestinationRuleSpecFluent.TrafficPolicyNested<A> withNewTrafficPolicy();
  public DestinationRuleSpecFluent.TrafficPolicyNested<A> withNewTrafficPolicyLike(TrafficPolicy item);
  public DestinationRuleSpecFluent.TrafficPolicyNested<A> editTrafficPolicy();
  public DestinationRuleSpecFluent.TrafficPolicyNested<A> editOrNewTrafficPolicy();
  public DestinationRuleSpecFluent.TrafficPolicyNested<A> editOrNewTrafficPolicyLike(TrafficPolicy item);
  public interface SubsetsNested<N> extends Nested<N>,SubsetFluent<DestinationRuleSpecFluent.SubsetsNested<N>>{
    public N and();
    public N endSubset();
    
  }
  public interface TrafficPolicyNested<N> extends Nested<N>,TrafficPolicyFluent<DestinationRuleSpecFluent.TrafficPolicyNested<N>>{
    public N and();
    public N endTrafficPolicy();
    
  }
  
}
